Pulsar v0.2.0 Pulsar.DashboardServer View Source
Responsible for managing a Dashboard, updating it based on received messages, and periodically flushing it to output.
The Pulsar module is the client API for creating and updating jobs.
The :pulsar application defines two configuration values:
:flush_interval- interval at which output is written to the console:active_highlight_duration- how long an updated job is “bright”
Both values are in milliseconds.
Updates to jobs accumluate between flushes; this reduces the amount of output that must be written.